@@ -29,7 +29,7 @@ class xyscanAbout : public QDialog
     Q_OBJECT
     
 public:
-    xyscanAbout( QWidget* parent = 0, Qt::WindowFlags fl = 0 );
+    xyscanAbout(QWidget* parent = 0);
 
 public slots:
     void accept();
